@@ -16,21 +16,17 @@
  */
 #include "fw_dunit.hpp"
 #include <geode/CqAttributesFactory.hpp>
-#include <geode/CqAttributes.hpp>
 #include <geode/CqListener.hpp>
 #include <geode/CqStatusListener.hpp>
-#include <geode/CqQuery.hpp>
 #include <geode/CqServiceStatistics.hpp>
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 #include <string>
+#include <sstream>
 
 #define ROOT_NAME "TestThinClientCq"
 #define ROOT_SCOPE DISTRIBUTED_ACK
 
 #include "CacheHelper.hpp"
 
-#include "QueryStrings.hpp"
 #include "QueryHelper.hpp"
 
 #include <geode/Query.hpp>
@@ -59,7 +55,7 @@ using apache::geode::client::QueryService;
 
 static bool m_isPdx = false;
 
-const char *locHostPort =
+const std::string locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 const char *cqNames[MAX_LISTNER] = {"MyCq_0", "MyCq_1", "MyCq_2", "MyCq_3",
                                     "MyCq_4", "MyCq_5", "MyCq_6", "MyCq_7"};
@@ -161,15 +157,15 @@ class MyCqListener : public CqListener {
     }
   }
 
-  void onEvent(const CqEvent &cqe) {
+  void onEvent(const CqEvent &cqe) override {
     //  LOG("MyCqListener::OnEvent called");
     updateCount(cqe);
   }
-  void onError(const CqEvent &cqe) {
+  void onError(const CqEvent &cqe) override {
     updateCount(cqe);
     //   LOG("MyCqListener::OnError called");
   }
-  void close() {
+  void close() override {
     //   LOG("MyCqListener::close called");
   }
 };
@@ -225,20 +221,22 @@ class MyCqStatusListener : public CqStatusListener {
     }
   }
 
-  void onEvent(const CqEvent &cqe) {
+  void onEvent(const CqEvent &cqe) override {
     LOGINFO("MyCqStatusListener::OnEvent %d called", m_id);
     updateCount(cqe);
   }
-  void onError(const CqEvent &cqe) {
+  void onError(const CqEvent &cqe) override {
     updateCount(cqe);
     LOGINFO("MyCqStatusListener::OnError %d called", m_id);
   }
-  void close() { LOGINFO("MyCqStatusListener::close %d called", m_id); }
-  void onCqDisconnected() {
+  void close() override {
+    LOGINFO("MyCqStatusListener::close %d called", m_id);
+  }
+  void onCqDisconnected() override {
     LOGINFO("MyCqStatusListener %d got onCqDisconnected", m_id);
     m_cqsDisconnectedCount++;
   }
-  void onCqConnected() {
+  void onCqConnected() override {
     LOGINFO("MyCqStatusListener %d got onCqConnected", m_id);
     m_cqsConnectedCount++;
   }
@@ -296,7 +294,7 @@ END_TASK_DEFINITION
 void createServer_group(bool locator, const char *XML) {
   LOG("Starting SERVER1...");
   if (isLocalServer) {
-    CacheHelper::initServer(1, XML, locator ? locHostPort : nullptr);
+    CacheHelper::initServer(1, XML, locator ? locHostPort : std::string{});
   }
   LOG("SERVER1 started");
 }
@@ -304,7 +302,7 @@ void createServer_group(bool locator, const char *XML) {
 void createServer_group2(bool locator, const char *XML) {
   LOG("Starting SERVER2...");
   if (isLocalServer) {
-    CacheHelper::initServer(2, XML, locator ? locHostPort : nullptr);
+    CacheHelper::initServer(2, XML, locator ? locHostPort : std::string{});
   }
   LOG("SERVER2 started");
 }
@@ -506,6 +504,7 @@ END_TASK_DEFINITION
 DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
   {
     QueryHelper::getHelper();
+    std::stringstream strm;
 
     auto pool =
         getHelper()->getCache()->getPoolManager().find(regionNamesCq[0]);
@@ -517,8 +516,6 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
       qs = getHelper()->cachePtr->getQueryService();
     }
 
-    char buf[1024];
-
     uint8_t i = 0;
     int j = 0;
     uint32_t inserts[MAX_LISTNER];
@@ -534,16 +531,18 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
 
     CqAttributesFactory cqFac;
     for (i = 0; i < MAX_LISTNER; i++) {
-      sprintf(buf, "get info for cq[%s]:", cqNames[i]);
-      LOG(buf);
+      strm.str("");
+      strm << "get info for cq[" << cqNames[i] << "]:";
+      LOG(strm.str());
+
       auto cqy = qs->getCq(cqNames[i]);
       auto cqStats = cqy->getStatistics();
-      sprintf(buf,
-              "Cq[%s]From CqStatistics: numInserts[%d], numDeletes[%d], "
-              "numUpdates[%d], numEvents[%d]",
-              cqNames[i], cqStats->numInserts(), cqStats->numDeletes(),
-              cqStats->numUpdates(), cqStats->numEvents());
-      LOG(buf);
+      strm.str("");
+      strm << "Cq[" << cqNames[i] << "] From CqStatistics : numInserts["
+           << cqStats->numInserts() << "], numDeletes[" << cqStats->numDeletes()
+           << "], numUpdates[" << cqStats->numUpdates() << "], numEvents["
+           << cqStats->numEvents() << "]";
+      LOG(strm.str());
       for (j = 0; j <= i; j++) {
         inserts[j] += cqStats->numInserts();
         updates[j] += cqStats->numUpdates();
@@ -552,9 +551,10 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
       }
       auto cqAttr = cqy->getCqAttributes();
       auto vl = cqAttr->getCqListeners();
-      sprintf(buf, "number of listeners for cq[%s] is %zd", cqNames[i],
-              vl.size());
-      LOG(buf);
+      strm.str("");
+      strm << "number of listeners for cq[" << cqNames[i] << "] is "
+           << vl.size();
+      LOG(strm.str());
       ASSERT(vl.size() == static_cast<size_t>(i + 1),
              "incorrect number of listeners");
       if (i == (MAX_LISTNER - 1)) {
@@ -565,17 +565,18 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
         }
         for (j = 0; j < MAX_LISTNER; j++) {
           MyCqListener *ml = myLl[j];
-          sprintf(buf,
-                  "MyCount for Listener[%d]: numInserts[%d], numDeletes[%d], "
-                  "numUpdates[%d], numEvents[%d]",
-                  j, ml->getNumInserts(), ml->getNumDeletes(),
-                  ml->getNumUpdates(), ml->getNumEvents());
-          LOG(buf);
-          sprintf(buf,
-                  "sum of stats for Listener[%d]: numInserts[%d], "
-                  "numDeletes[%d], numUpdates[%d], numEvents[%d]",
-                  j, inserts[j], deletes[j], updates[j], events[j]);
-          LOG(buf);
+          strm.str("");
+          strm << "MyCount for Listener[" << j << "]: numInserts["
+               << ml->getNumInserts() << "], numDeletes[" << ml->getNumDeletes()
+               << "], numUpdates[" << ml->getNumUpdates() << "], numEvents["
+               << ml->getNumEvents() << "]";
+          LOG(strm.str());
+          strm.str("");
+          strm << "sum of stats for Listener[" << j << "]: numInserts["
+               << inserts[j] << "], numDeletes[" << deletes[j]
+               << "], numUpdates[" << updates[j] << "], numEvents[" << events[j]
+               << "]";
+          LOG(strm.str());
           ASSERT(ml->getNumInserts() == inserts[j],
                  "accumulative insert count incorrect");
           ASSERT(ml->getNumUpdates() == updates[j],
@@ -590,20 +591,23 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
         auto ptr = vl[0];
         cqAttrMtor.removeCqListener(ptr);
         vl = cqAttr->getCqListeners();
-        sprintf(buf, "number of listeners for cq[%s] is %zd", cqNames[i],
-                vl.size());
-        LOG(buf);
+        strm.str("");
+        strm << "number of listeners for cq[" << cqNames[i] << "] is "
+             << vl.size();
+        LOG(strm.str());
         ASSERT(vl.size() == i, "incorrect number of listeners");
       }
     }
+
     try {
       auto cqy = qs->getCq(cqNames[1]);
       cqy->stop();
 
       cqy = qs->getCq(cqNames[6]);
 
-      sprintf(buf, "cq[%s] should have been running!", cqNames[6]);
-      ASSERT(cqy->isRunning() == true, buf);
+      strm.str("");
+      strm << "cq[" << cqNames[6] << "] should have been running!";
+      ASSERT(cqy->isRunning() == true, strm.str());
       bool got_exception = false;
       try {
         cqy->execute();
@@ -615,23 +619,27 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
         LOG(failmsg.c_str());
         got_exception = true;
       }
-      sprintf(buf, "cq[%s] should gotten exception!", cqNames[6]);
-      ASSERT(got_exception == true, buf);
+      strm.str("");
+      strm << "cq[" << cqNames[6] << "] should have gotten exception!";
+      ASSERT(got_exception == true, strm.str());
 
       cqy->stop();
 
-      sprintf(buf, "cq[%s] should have been stopped!", cqNames[6]);
-      ASSERT(cqy->isStopped() == true, buf);
+      strm.str("");
+      strm << "cq[" << cqNames[6] << "] should have been stopped!";
+      ASSERT(cqy->isStopped() == true, strm.str());
 
       cqy = qs->getCq(cqNames[2]);
       cqy->close();
 
-      sprintf(buf, "cq[%s] should have been closed!", cqNames[2]);
-      ASSERT(cqy->isClosed() == true, buf);
+      strm.str("");
+      strm << "cq[" << cqNames[2] << "] should have been closed!";
+      ASSERT(cqy->isClosed() == true, strm.str());
 
       cqy = qs->getCq(cqNames[2]);
-      sprintf(buf, "cq[%s] should have been removed after close!", cqNames[2]);
-      ASSERT(cqy == nullptr, buf);
+      strm.str("");
+      strm << "cq[" << cqNames[2] << "] should have been removed after close!";
+      ASSERT(cqy == nullptr, strm.str());
     } catch (Exception &excp) {
       std::string failmsg = "";
       failmsg += excp.getName();
@@ -643,24 +651,13 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
     }
     auto serviceStats = qs->getCqServiceStatistics();
     ASSERT(serviceStats != nullptr, "serviceStats is nullptr");
-    sprintf(buf,
-            "numCqsActive=%d, numCqsCreated=%d, "
-            "numCqsClosed=%d,numCqsStopped=%d, numCqsOnClient=%d",
-            serviceStats->numCqsActive(), serviceStats->numCqsCreated(),
-            serviceStats->numCqsClosed(), serviceStats->numCqsStopped(),
-            serviceStats->numCqsOnClient());
-    LOG(buf);
-    /*
-    for(i=0; i < MAX_LISTNER; i++)
-    {
-    auto cqy = qs->getCq(cqNames[i]);
-     CqState state = cqy->getState();
-     CqState cqState;
-     cqState.setState(state);
-     sprintf(buf, "cq[%s] is in state[%s]", cqNames[i], cqState.toString());
-     LOG(buf);
-    }
-    */
+    strm.str("");
+    strm << "numCqsActive=" << serviceStats->numCqsActive()
+         << ", numCqsCreated = " << serviceStats->numCqsCreated()
+         << ", numCqsClosed= " << serviceStats->numCqsClosed()
+         << ", numCqsStopped=" << serviceStats->numCqsStopped()
+         << ", numCqsOnClient=" << serviceStats->numCqsOnClient();
+    LOG(strm.str());
 
     ASSERT(serviceStats->numCqsActive() == 6, "active count incorrect!");
     ASSERT(serviceStats->numCqsCreated() == 9, "created count incorrect!");
@@ -679,13 +676,13 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
       FAIL(failmsg.c_str());
       LOG(excp.getStackTrace());
     }
-    sprintf(buf,
-            "numCqsActive=%d, numCqsCreated=%d, "
-            "numCqsClosed=%d,numCqsStopped=%d, numCqsOnClient=%d",
-            serviceStats->numCqsActive(), serviceStats->numCqsCreated(),
-            serviceStats->numCqsClosed(), serviceStats->numCqsStopped(),
-            serviceStats->numCqsOnClient());
-    LOG(buf);
+    strm.str("");
+    strm << "numCqsActive=" << serviceStats->numCqsActive()
+         << ", numCqsCreated = " << serviceStats->numCqsCreated()
+         << ", numCqsClosed= " << serviceStats->numCqsClosed()
+         << ", numCqsStopped=" << serviceStats->numCqsStopped()
+         << ", numCqsOnClient=" << serviceStats->numCqsOnClient();
+    LOG(strm.str());
     ASSERT(serviceStats->numCqsActive() == 0, "active count incorrect!");
     ASSERT(serviceStats->numCqsCreated() == 9, "created count incorrect!");
     ASSERT(serviceStats->numCqsClosed() == 1, "closed count incorrect!");
@@ -702,13 +699,13 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
       FAIL(failmsg.c_str());
       LOG(excp.getStackTrace());
     }
-    sprintf(buf,
-            "numCqsActive=%d, numCqsCreated=%d, "
-            "numCqsClosed=%d,numCqsStopped=%d, numCqsOnClient=%d",
-            serviceStats->numCqsActive(), serviceStats->numCqsCreated(),
-            serviceStats->numCqsClosed(), serviceStats->numCqsStopped(),
-            serviceStats->numCqsOnClient());
-    LOG(buf);
+    strm.str("");
+    strm << "numCqsActive=" << serviceStats->numCqsActive()
+         << ", numCqsCreated = " << serviceStats->numCqsCreated()
+         << ", numCqsClosed= " << serviceStats->numCqsClosed()
+         << ", numCqsStopped=" << serviceStats->numCqsStopped()
+         << ", numCqsOnClient=" << serviceStats->numCqsOnClient();
+    LOG(strm.str());
     ASSERT(serviceStats->numCqsActive() == 0, "active count incorrect!");
     ASSERT(serviceStats->numCqsCreated() == 9, "created count incorrect!");
     ASSERT(serviceStats->numCqsClosed() == 9, "closed count incorrect!");
@@ -890,13 +887,15 @@ DUNIT_TASK_DEFINITION(CLIENT1, createCQ_Pool)
     char KeyStr[256] = {0};
     char valStr[256] = {0};
     for (int i = 1; i <= 5; i++) {
-      ACE_OS::snprintf(KeyStr, 256, "Key-%d ", i);
-      ACE_OS::snprintf(valStr, 256, "val-%d ", i);
-      auto keyport = CacheableKey::create(KeyStr);
-      auto valport = CacheableString::create(valStr);
+      std::string key = "Key-" + std::to_string(i);
+      std::string value = "val-" + std::to_string(i);
+
+      auto keyport = CacheableKey::create(key);
+      auto valport = CacheableString::create(value);
+
       regPtr0->put(keyport, valport);
       regPtr1->put(keyport, valport);
-      SLEEP(10 * 1000);  // sleep a while to allow server query to complete
+      SLEEP(10000);  // sleep a while to allow server query to complete
     }
     LOGINFO("putEntries complete");
 
@@ -1030,16 +1029,16 @@ DUNIT_TASK_DEFINITION(CLIENT1, putEntries)
     auto regPtr0 = getHelper()->getRegion(regionName);
     auto regPtr1 = getHelper()->getRegion(regionName1);
     std::shared_ptr<Cacheable> val = nullptr;
-    char KeyStr[256] = {0};
-    char valStr[256] = {0};
     for (int i = 1; i <= 5; i++) {
-      ACE_OS::snprintf(KeyStr, 256, "Key-%d ", i);
-      ACE_OS::snprintf(valStr, 256, "val-%d ", i);
-      auto keyport = CacheableKey::create(KeyStr);
-      auto valport = CacheableString::create(valStr);
+      std::string key = "Key-" + std::to_string(i);
+      std::string value = "val-" + std::to_string(i);
+
+      auto keyport = CacheableKey::create(key);
+      auto valport = CacheableString::create(value);
+
       regPtr0->put(keyport, valport);
       regPtr1->put(keyport, valport);
-      SLEEP(10 * 1000);  // sleep a while to allow server query to complete
+      SLEEP(10000);  // sleep a while to allow server query to complete
     }
     LOGINFO("putEntries complete");
   }
@@ -1098,15 +1097,15 @@ DUNIT_TASK_DEFINITION(CLIENT1, ProcessCQ)
 
     auto regPtr0 = getHelper()->getRegion(regionName);
     std::shared_ptr<Cacheable> val = nullptr;
-    char KeyStr[256] = {0};
-    char valStr[256] = {0};
     for (int i = 1; i <= 5; i++) {
-      ACE_OS::snprintf(KeyStr, 256, "Key-%d ", i);
-      ACE_OS::snprintf(valStr, 256, "val-%d ", i);
-      auto keyport = CacheableKey::create(KeyStr);
-      auto valport = CacheableString::create(valStr);
+      std::string key = "Key-" + std::to_string(i);
+      std::string value = "val-" + std::to_string(i);
+
+      auto keyport = CacheableKey::create(key);
+      auto valport = CacheableString::create(value);
+
       regPtr0->put(keyport, valport);
-      SLEEP(10 * 1000);  // sleep a while to allow server query to complete
+      SLEEP(10000);  // sleep a while to allow server query to complete
     }
     LOGINFO("putEntries complete");
 
@@ -1157,12 +1156,14 @@ DUNIT_TASK_DEFINITION(CLIENT1, ProcessCQ)
     myStatusCq2->clear();
 
     for (int i = 1; i <= 5; i++) {
-      ACE_OS::snprintf(KeyStr, 256, "Key-%d ", i);
-      ACE_OS::snprintf(valStr, 256, "val-%d ", i);
-      auto keyport = CacheableKey::create(KeyStr);
-      auto valport = CacheableString::create(valStr);
+      std::string key = "Key-" + std::to_string(i);
+      std::string value = "val-" + std::to_string(i);
+
+      auto keyport = CacheableKey::create(key);
+      auto valport = CacheableString::create(value);
+
       regPtr0->put(keyport, valport);
-      SLEEP(10 * 1000);  // sleep a while to allow server query to complete
+      SLEEP(10000);  // sleep a while to allow server query to complete
     }
     LOGINFO("putEntries complete again");
 
