@@ -15,8 +15,6 @@
  * limitations under the License.
  */
 #include "fw_dunit.hpp"
-#include <ace/OS.h>
-#include <ace/High_Res_Timer.h>
 #include <string>
 
 #define ROOT_NAME "testThinClientRemoteQueryRS"
@@ -58,7 +56,7 @@ bool isLocator = false;
 bool isLocalServer = false;
 
 const char *poolNames[] = {"Pool1", "Pool2", "Pool3"};
-const char *locHostPort =
+const std::string locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 bool isPoolConfig = false;  // To track if pool case is running
 const char *qRegionNames[] = {"Portfolios", "Positions", "Portfolios2",
@@ -83,7 +81,7 @@ void stepOne() {
     // ignore exception
   }
   isPoolConfig = true;
-  createPool(poolNames[0], locHostPort, nullptr, 0, true);
+  createPool(poolNames[0], locHostPort, {}, 0, true);
   createRegionAndAttachPool(qRegionNames[0], USE_ACK, poolNames[0]);
   createRegionAndAttachPool(qRegionNames[1], USE_ACK, poolNames[0]);
   createRegionAndAttachPool(qRegionNames[2], USE_ACK, poolNames[0]);
@@ -150,10 +148,8 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepThree)
 
     QueryHelper *qh = &QueryHelper::getHelper();
 
-    char buf[100];
-    sprintf(buf, "SetSize %zd, NumSets %zd", qh->getPortfolioSetSize(),
-            qh->getPortfolioNumSets());
-    LOG(buf);
+    LOG(std::string("SetSize") + std::to_string(qh->getPortfolioSetSize()) +
+        ", NumSets " + std::to_string(qh->getPortfolioNumSets()));
 
     if (!m_isPdx) {
       qh->populatePortfolioData(regPtr0, qh->getPortfolioSetSize(),
@@ -202,9 +198,8 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
       auto qry = qs->newQuery(resultsetQueriesOPL[i].query());
       auto results = qry->execute();
       if (!qh->verifyRS(results, resultsetRowCountsOPL[i])) {
-        char failmsg[100] = {0};
-        ACE_OS::sprintf(failmsg, "Query verify failed for query index %d", i);
-        ASSERT(false, failmsg);
+        ASSERT(false,
+               "Query verify failed for query index " + std::to_string(i));
       }
 
       auto rsptr = std::dynamic_pointer_cast<ResultSet>(results);
@@ -216,21 +211,21 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
         if (!m_isPdx) {
           auto ser = (*rsptr)[rows];
           if (auto portfolio = std::dynamic_pointer_cast<Portfolio>(ser)) {
-            printf(
-                "   query idx %d pulled portfolio object ID %d, pkid  :: %s\n",
-                i, portfolio->getID(), portfolio->getPkid()->value().c_str());
+            std::cout << "   query idx " << i << " pulled portfolio object ID "
+                      << portfolio->getID()
+                      << ", pkid  :: " << portfolio->getPkid()->value() << "\n";
           } else if (auto position = std::dynamic_pointer_cast<Position>(ser)) {
-            printf(
-                "   query idx %d pulled position object secId %s, shares  :: "
-                "%d\n",
-                i, position->getSecId()->value().c_str(),
-                position->getSharesOutstanding());
+            std::cout << "   query idx " << i
+                      << " pulled position object secId "
+                      << position->getSecId()->value()
+                      << ", shares  :: " << position->getSharesOutstanding()
+                      << "\n";
           } else {
             if (ser != nullptr) {
-              printf(" query idx %d pulled object %s \n", i,
-                     ser->toString().c_str());
+              std::cout << " query idx " << i << " pulled object "
+                        << ser->toString() << " \n";
             } else {
-              printf("   query idx %d pulled bad object \n", i);
+              std::cout << "   query idx " << i << " pulled bad object \n";
               FAIL("Unexpected object received in query");
             }
           }
@@ -238,24 +233,22 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
           auto pdxser = (*rsptr)[rows];
           if (auto portfoliopdx =
                   std::dynamic_pointer_cast<PortfolioPdx>(pdxser)) {
-            printf(
-                "   query idx %d pulled portfolioPdx object ID %d, pkid %s  :: "
-                "\n",
-                i, portfoliopdx->getID(), portfoliopdx->getPkid().c_str());
+            std::cout << "   query idx " << i
+                      << " pulled portfolioPdx object ID "
+                      << portfoliopdx->getID() << ", pkid  "
+                      << portfoliopdx->getPkid() << "\n";
           } else if (auto positionpdx =
                          std::dynamic_pointer_cast<PositionPdx>(pdxser)) {
-            printf(
-                "   query idx %d pulled positionPdx object secId %s, shares %d "
-                " "
-                ":: \n",
-                i, positionpdx->getSecId().c_str(),
-                positionpdx->getSharesOutstanding());
+            std::cout << "   query idx " << i
+                      << " pulled positionPdx object secId "
+                      << positionpdx->getSecId() << ", shares "
+                      << positionpdx->getSharesOutstanding() << "  :: \n";
           } else {
             if (pdxser != nullptr) {
-              printf(" query idx %d pulled object %s  :: \n", i,
-                     pdxser->toString().c_str());
+              std::cout << " query idx " << i << " pulled object "
+                        << pdxser->toString() << "  :: \n";
             } else {
-              printf("   query idx %d pulled bad object  :: \n", i);
+              std::cout << "   query idx " << i << " pulled bad object  :: \n";
               FAIL("Unexpected object received in query");
             }
           }
@@ -264,7 +257,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
     }
 
     if (!doAnyErrorOccured) {
-      printf("HURRAY !! StepFour PASSED \n\n");
+      std::cout << "HURRAY !! StepFour PASSED \n\n";
     } else {
       FAIL("Failed in StepFour verification");
     }
@@ -303,8 +296,8 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
                                         ? resultsetRowCounts[i]
                                         : resultsetRowCounts[i] *
                                               qh->getPortfolioNumSets()))) {
-          char failmsg[100] = {0};
-          ACE_OS::sprintf(failmsg, "Query verify failed for query index %d", i);
+          std::string failmsg =
+              "Query verify failed for query index " + std::to_string(i);
           ASSERT(false, failmsg);
         }
 
@@ -317,23 +310,23 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
           if (!m_isPdx) {
             auto ser = (*rsptr)[rows];
             if (auto portfolio = std::dynamic_pointer_cast<Portfolio>(ser)) {
-              printf(
-                  "   query idx %d pulled portfolio object ID %d, pkid  :: "
-                  "%s\n",
-                  i, portfolio->getID(), portfolio->getPkid()->value().c_str());
+              std::cout << "   query idx " << i
+                        << " pulled portfolio object ID " << portfolio->getID()
+                        << ", pkid  :: " << portfolio->getPkid()->value()
+                        << "\n";
             } else if (auto position =
                            std::dynamic_pointer_cast<Position>(ser)) {
-              printf(
-                  "   query idx %d pulled position object secId %s, shares  :: "
-                  "%d\n",
-                  i, position->getSecId()->value().c_str(),
-                  position->getSharesOutstanding());
+              std::cout << "   query idx " << i
+                        << " pulled position object secId "
+                        << position->getSecId()->value()
+                        << ", shares  :: " << position->getSharesOutstanding()
+                        << "\n";
             } else {
               if (ser != nullptr) {
-                printf(" query idx %d pulled object %s \n", i,
-                       ser->toString().c_str());
+                std::cout << " query idx " << i << " pulled object "
+                          << ser->toString() << "\n";
               } else {
-                printf("   query idx %d pulled bad object \n", i);
+                std::cout << "   query idx " << i << " pulled bad object \n";
                 FAIL("Unexpected object received in query");
               }
             }
@@ -341,25 +334,22 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
             auto pdxser = (*rsptr)[rows];
             if (auto portfoliopdx =
                     std::dynamic_pointer_cast<PortfolioPdx>(pdxser)) {
-              printf(
-                  "   query idx %d pulled portfolioPdx object ID %d, pkid %s  "
-                  ":: "
-                  "\n",
-                  i, portfoliopdx->getID(), portfoliopdx->getPkid().c_str());
+              std::cout << "   query idx " << i
+                        << " pulled portfoliopdx object ID "
+                        << portfoliopdx->getID()
+                        << ", pkid  :: " << portfoliopdx->getPkid() << "\n";
             } else if (auto positionpdx =
                            std::dynamic_pointer_cast<PositionPdx>(pdxser)) {
-              printf(
-                  "   query idx %d pulled positionPdx object secId %s, shares "
-                  "%d "
-                  " :: \n",
-                  i, positionpdx->getSecId().c_str(),
-                  positionpdx->getSharesOutstanding());
+              std::cout << "   query idx " << i
+                        << " pulled positionpdx object secId "
+                        << positionpdx->getSecId() << ", shares  :: "
+                        << positionpdx->getSharesOutstanding() << "\n";
             } else {
               if (pdxser != nullptr) {
-                printf(" query idx %d pulled object %s  :: \n", i,
-                       pdxser->toString().c_str());
+                std::cout << " query idx " << i << " pulled object "
+                          << pdxser->toString() << "\n";
               } else {
-                printf("   query idx %d pulled bad object  :: \n", i);
+                std::cout << "   query idx " << i << " pulled bad object \n";
                 FAIL("Unexpected object received in query");
               }
             }
@@ -369,7 +359,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
     }
 
     if (!doAnyErrorOccured) {
-      printf("HURRAY !! We PASSED \n\n");
+      std::cout << "HURRAY !! We PASSED \n\n";
     } else {
       FAIL("Failed in StepFive verification");
     }
@@ -414,8 +404,8 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepSix)
                                         ? resultsetRowCountsPQ[i]
                                         : resultsetRowCountsPQ[i] *
                                               qh->getPortfolioNumSets()))) {
-          char failmsg[100] = {0};
-          ACE_OS::sprintf(failmsg, "Query verify failed for query index %d", i);
+          std::string failmsg =
+              "Query verify failed for query index " + std::to_string(i);
           ASSERT(false, failmsg);
         }
 
@@ -428,23 +418,23 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepSix)
           if (!m_isPdx) {
             auto ser = (*rsptr)[rows];
             if (auto portfolio = std::dynamic_pointer_cast<Portfolio>(ser)) {
-              printf(
-                  "   query idx %d pulled portfolio object ID %d, pkid %s : \n",
-                  i, portfolio->getID(), portfolio->getPkid()->value().c_str());
+              std::cout << "   query idx " << i
+                        << " pulled portfolio object ID " << portfolio->getID()
+                        << ", pkid  :: " << portfolio->getPkid()->value()
+                        << "\n";
             } else if (auto position =
                            std::dynamic_pointer_cast<Position>(ser)) {
-              printf(
-                  "   query idx %d pulled position object secId %s, shares %d  "
-                  ": "
-                  "\n",
-                  i, position->getSecId()->value().c_str(),
-                  position->getSharesOutstanding());
+              std::cout << "   query idx " << i
+                        << " pulled position object secId "
+                        << position->getSecId()->value()
+                        << ", shares  :: " << position->getSharesOutstanding()
+                        << "\n";
             } else {
               if (ser != nullptr) {
-                printf(" query idx %d pulled object %s  : \n", i,
-                       ser->toString().c_str());
+                std::cout << " query idx " << i << " pulled object "
+                          << ser->toString() << "  : \n";
               } else {
-                printf("   query idx %d pulled bad object  \n", i);
+                std::cout << "   query idx " << i << " pulled bad object  \n";
                 FAIL("Unexpected object received in query");
               }
             }
@@ -452,25 +442,22 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepSix)
             auto ser = (*rsptr)[rows];
             if (auto portfoliopdx =
                     std::dynamic_pointer_cast<PortfolioPdx>(ser)) {
-              printf(
-                  "   query idx %d pulled portfolioPdx object ID %d, pkid %s  "
-                  ": "
-                  "\n",
-                  i, portfoliopdx->getID(), portfoliopdx->getPkid().c_str());
+              std::cout << "   query idx " << i
+                        << " pulled portfoliopdx object ID "
+                        << portfoliopdx->getID()
+                        << ", pkid  :: " << portfoliopdx->getPkid() << "\n";
             } else if (auto positionpdx =
                            std::dynamic_pointer_cast<PositionPdx>(ser)) {
-              printf(
-                  "   query idx %d pulled positionPdx object secId %s, shares "
-                  "%d "
-                  " : \n",
-                  i, positionpdx->getSecId().c_str(),
-                  positionpdx->getSharesOutstanding());
+              std::cout << "   query idx " << i
+                        << " pulled positionPdx object secId "
+                        << positionpdx->getSecId() << ", shares "
+                        << positionpdx->getSharesOutstanding() << "  :: \n";
             } else {
               if (ser != nullptr) {
-                printf(" query idx %d pulled object %s : \n", i,
-                       ser->toString().c_str());
+                std::cout << " query idx " << i << " pulled object "
+                          << ser->toString() << " \n";
               } else {
-                printf("   query idx %d pulled bad object\n", i);
+                std::cout << "   query idx " << i << " pulled bad object\n";
                 FAIL("Unexpected object received in query");
               }
             }
@@ -480,7 +467,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepSix)
     }
 
     if (!doAnyErrorOccured) {
-      printf("HURRAY !! We PASSED \n\n");
+      std::cout << "HURRAY !! We PASSED \n\n";
     } else {
       FAIL("Failed in StepSix verification");
     }
@@ -505,10 +492,9 @@ DUNIT_TASK_DEFINITION(CLIENT1, DoQueryRSError)
 
         try {
           auto results = qry->execute();
+          std::string failmsg =
+              "Query exception didnt occur for index " + std::to_string(i);
 
-          char failmsg[100] = {0};
-          ACE_OS::sprintf(failmsg, "Query exception didnt occur for index %d",
-                          i);
           LOG(failmsg);
           FAIL(failmsg);
         } catch (apache::geode::client::QueryException &) {
