@@ -24,6 +24,7 @@
 
 #include <geode/FixedPartitionResolver.hpp>
 
+#include "CacheImpl.hpp"
 #include "ClientMetadata.hpp"
 #include "TcrConnectionManager.hpp"
 #include "TcrMessage.hpp"
@@ -36,8 +37,6 @@ namespace client {
 
 const BucketStatus::clock::time_point BucketStatus::m_noTimeout{};
 
-const char* ClientMetadataService::NC_CMDSvcThread = "NC CMDSvcThread";
-
 ClientMetadataService::ClientMetadataService(ThinClientPoolDM* pool)
     : m_run(false),
       m_pool(pool),
@@ -65,7 +64,7 @@ void ClientMetadataService::stop() {
 }
 
 void ClientMetadataService::svc() {
-  DistributedSystemImpl::setThreadName(NC_CMDSvcThread);
+  Log::setThreadName("NC CMDSvcThread");
 
   LOGINFO("ClientMetadataService started for pool " + m_pool->getName());
 
@@ -120,6 +119,14 @@ void ClientMetadataService::getClientPRMetadata(const char* regionFullPath) {
     if (err == GF_NOERR &&
         reply.getMessageType() ==
             TcrMessage::RESPONSE_CLIENT_PARTITION_ATTRIBUTES) {
+      // By convention, server returns -1 bucket count to indicate replicated
+      // region
+      if (reply.getNumBuckets() == -1) {
+        LOGDEBUG(
+            "ClientMetadataService::getClientPRMetadata: region is"
+            "replicated, not partitioned - no metadata");
+        return;
+      }
       cptr = std::make_shared<ClientMetadata>(reply.getNumBuckets(),
                                               reply.getColocatedWith(), m_pool,
                                               reply.getFpaSet());
@@ -149,6 +156,7 @@ void ClientMetadataService::getClientPRMetadata(const char* regionFullPath) {
           m_regionMetadataLock);
       m_regionMetaDataMap[path] = newCptr;
       LOGINFO("Updated client meta data");
+      m_cache->setPrMetadataUpdatedFlag(true);
     }
   } else {
     newCptr = SendClientPRMetadata(colocatedWith.c_str(), cptr);
@@ -162,6 +170,7 @@ void ClientMetadataService::getClientPRMetadata(const char* regionFullPath) {
       m_regionMetaDataMap[colocatedWith.c_str()] = newCptr;
       m_regionMetaDataMap[path] = newCptr;
       LOGINFO("Updated client meta data");
+      m_cache->setPrMetadataUpdatedFlag(true);
     }
   }
 }
@@ -172,8 +181,6 @@ std::shared_ptr<ClientMetadata> ClientMetadataService::SendClientPRMetadata(
       new DataOutput(m_cache->createDataOutput(m_pool)), regionPath);
   TcrMessageReply reply(true, nullptr);
   // send this message to server and get metadata from server.
-  LOGFINE("Now sending GET_CLIENT_PR_METADATA for getting from server: %s",
-          regionPath);
   std::shared_ptr<Region> region = nullptr;
   GfErrType err = m_pool->sendSyncRequest(request, reply);
   if (err == GF_NOERR &&
@@ -185,7 +192,9 @@ std::shared_ptr<ClientMetadata> ClientMetadataService::SendClientPRMetadata(
       }
     }
     auto metadata = reply.getMetadata();
-    if (metadata == nullptr) return nullptr;
+    if (metadata == nullptr) {
+      return nullptr;
+    }
     if (metadata->empty()) {
       delete metadata;
       return nullptr;
@@ -299,8 +308,8 @@ void ClientMetadataService::enqueueForMetadataRefresh(
   if (region != nullptr) {
     auto tcrRegion = dynamic_cast<ThinClientRegion*>(region.get());
     {
-      TryWriteGuard guardRegionMetaDataRefresh(
-          tcrRegion->getMataDataMutex(), tcrRegion->getMetaDataRefreshed());
+      boost::unique_lock<boost::shared_mutex> guard{
+          tcrRegion->getMetadataMutex()};
       if (tcrRegion->getMetaDataRefreshed()) {
         return;
       }
@@ -357,8 +366,9 @@ ClientMetadataService::getServerToFilterMap(
       clientMetadata->getServerLocation(bucketId, isPrimary, serverLocation,
                                         version);
       if (!(serverLocation && serverLocation->isValid())) {
-        keysWhichLeft.push_back(key);
-        continue;
+        // If we're missing any metadata, give up.  This will cause us to revert
+        // to multi-hop, which is consistent with the Java client.
+        return nullptr;
       }
 
       buckets[bucketId] = serverLocation;
@@ -559,7 +569,6 @@ std::shared_ptr<BucketServerLocation> ClientMetadataService::findNextServer(
 std::shared_ptr<ClientMetadataService::ServerToBucketsMap>
 ClientMetadataService::pruneNodes(
     const std::shared_ptr<ClientMetadata>& metadata, const BucketSet& buckets) {
-  BucketSet bucketSetWithoutServer;
   ServerToBucketsMap serverToBucketsMap;
 
   auto prunedServerToBucketsMap = std::make_shared<ServerToBucketsMap>();
@@ -568,12 +577,10 @@ ClientMetadataService::pruneNodes(
     const auto locations = metadata->adviseServerLocations(bucketId);
     if (locations.size() == 0) {
       LOGDEBUG(
-          "ClientMetadataService::pruneNodes Since no server location "
-          "available for bucketId = %d  putting it into "
-          "bucketSetWithoutServer ",
+          "ClientMetadataService::pruneNodes Use non single-hop path "
+          "since no server location is available for bucketId = %d",
           bucketId);
-      bucketSetWithoutServer.insert(bucketId);
-      continue;
+      return nullptr;
     }
 
     for (const auto& location : locations) {
@@ -654,11 +661,6 @@ ClientMetadataService::pruneNodes(
     serverToBucketsMap.erase(server);
   }
 
-  const auto& itrRes2 = prunedServerToBucketsMap->begin();
-  for (const auto& itr : bucketSetWithoutServer) {
-    itrRes2->second->insert(itr);
-  }
-
   return prunedServerToBucketsMap;
 }
 
